<style>
.mint-green-code-block {
    background-color: #98FF98; /* Mint green background */
    color: black;              /* Black text color */
    padding: 10px;             /* Padding around the text */
    border-radius: 5px;        /* Rounded corners */
}
.mint-green-code-block b {
    font-weight: bold;         /* Bold text */
}
</style>


How to cite Story Navigator
=======
![](../../doc/widgets/images/storynavigator_logo_small.png)


If you use this software in your work, please cite it using the following metadata [(Learn more about CITATION files).](https://docs.github.com/en/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-citation-files)

You can do this easily with one of these options:
- The 'cite this repository' menu in the right tab at https://github.com/navigating-stories/orange-story-navigator.
- The [citation file](https://github.com/navigating-stories/orange-story-navigator/blob/docs/CITATION.cff). 
- If you prefer to copypaste, here you have the APA and BibTex strings:  
<p class="mint-green-code-block">
<b>APA</b>: Moodley, K. Hafner, F., Lüken, M., Tjong Kim Sang, E. Smeets, S. & 
Vroegh, T.(2024). Orange-story-navigator (Version 0.0.32) [Computer software].
https://github.com/navigating-stories/orange-story-navigator
</p>
<p class="mint-green-code-block">
<b>BibTex</b>: @software{orange-story-navigator,
  author = {Moodley, Kody, Hafner, Flavio, Lüken, Malte, Tjong Kim Sang, Erik,
  Smeets, Stef. and Vroegh, Thijs}, title = {orange-story-navigator 
  (Version 0.0.32) [Computer software]},
  url = {https://github.com/navigating-stories/orange-story-navigator}
</p>